@@ -3,7 +3,7 @@
  * \brief abstraction for all consumer services
  * \see mlt_consumer_s
  *
- * Copyright (C) 2003-2015 Meltytech, LLC
+ * Copyright (C) 2003-2019 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -65,7 +65,7 @@ typedef struct
 	double fps;
 	int channels;
 	int frequency;
-
+	int speed;
 	/* additional fields added for the parallel work queue */
 	mlt_deque worker_threads;
 	pthread_mutex_t done_mutex;
@@ -208,7 +208,7 @@ static void mlt_consumer_property_changed( mlt_properties owner, mlt_consumer se
 {
 	if ( !strcmp( name, "mlt_profile" ) )
 	{
-		// Get the properies
+		// Get the properties
 		mlt_properties properties = MLT_CONSUMER_PROPERTIES( self );
 
 		// Get the current profile
@@ -516,7 +516,7 @@ int mlt_consumer_start( mlt_consumer self )
 	// Stop listening to the property-changed event
 	mlt_event_block( priv->event_listener );
 
-	// Get the properies
+	// Get the properties
 	mlt_properties properties = MLT_CONSUMER_PROPERTIES( self );
 
 	// Determine if there's a test card producer
@@ -617,7 +617,7 @@ int mlt_consumer_put_frame( mlt_consumer self, mlt_frame frame )
 {
 	int error = 1;
 
-	// Get the service assoicated to the consumer
+	// Get the service associated to the consumer
 	mlt_service service = MLT_CONSUMER_SERVICE( self );
 
 	if ( mlt_service_producer( service ) == NULL )
@@ -663,7 +663,7 @@ mlt_frame mlt_consumer_get_frame( mlt_consumer self )
 	// Frame to return
 	mlt_frame frame = NULL;
 
-	// Get the service assoicated to the consumer
+	// Get the service associated to the consumer
 	mlt_service service = MLT_CONSUMER_SERVICE( self );
 
 	// Get the consumer properties
@@ -774,9 +774,6 @@ static void *consumer_read_ahead_thread( void *arg )
 	// See if audio is turned off
 	int audio_off = mlt_properties_get_int( properties, "audio_off" );
 
-	// Get the maximum size of the buffer
-	int buffer = mlt_properties_get_int( properties, "buffer" ) + 1;
-
 	// General frame variable
 	mlt_frame frame = NULL;
 	uint8_t *image = NULL;
@@ -805,6 +802,7 @@ static void *consumer_read_ahead_thread( void *arg )
 
 	// Get the first frame
 	frame = mlt_consumer_get_frame( self );
+	priv->speed = mlt_properties_get_int( MLT_FRAME_PROPERTIES( frame ), "_speed" );
 
 	if ( frame )
 	{
@@ -833,6 +831,9 @@ static void *consumer_read_ahead_thread( void *arg )
 	// Continue to read ahead
 	while ( priv->ahead )
 	{
+		// Get the maximum size of the buffer
+		int buffer = (priv->speed == 0) ? 1 : MAX(mlt_properties_get_int( properties, "buffer" ), 0) + 1;
+	
 		// Put the current frame into the queue
 		pthread_mutex_lock( &priv->queue_mutex );
 		while( priv->ahead && mlt_deque_count( priv->queue ) >= buffer )
@@ -858,6 +859,7 @@ static void *consumer_read_ahead_thread( void *arg )
 		if ( frame == NULL )
 			continue;
 		pos = mlt_frame_get_position( frame );
+		priv->speed = mlt_properties_get_int( MLT_FRAME_PROPERTIES( frame ), "_speed" );
 
 		// WebVfx uses this to setup a consumer-stopping event handler.
 		mlt_properties_set_data( MLT_FRAME_PROPERTIES( frame ), "consumer", self, 0, NULL, NULL );
@@ -873,7 +875,7 @@ static void *consumer_read_ahead_thread( void *arg )
 		}
 
 		// All non-normal playback frames should be shown
-		if ( mlt_properties_get_int( MLT_FRAME_PROPERTIES( frame ), "_speed" ) != 1 )
+		if ( priv->speed != 1 )
 		{
 #ifdef DEINTERLACE_ON_NOT_NORMAL_SPEED
 			mlt_properties_set_int( MLT_FRAME_PROPERTIES( frame ), "consumer_deinterlace", 1 );
@@ -1151,7 +1153,7 @@ static void consumer_work_start( mlt_consumer self )
 	priv->ahead = 1;
 	priv->threads = thread;
 	
-	// These keep track of the accelleration of frame dropping or recovery.
+	// These keep track of the acceleration of frame dropping or recovery.
 	priv->consecutive_dropped = 0;
 	priv->consecutive_rendered = 0;
 	
@@ -1188,9 +1190,12 @@ static void consumer_work_start( mlt_consumer self )
 
 		while ( n-- )
 		{
-			if ( pthread_create( thread, &thread_attributes, consumer_worker_thread, self ) < 0 )
+			if ( pthread_create( thread, &thread_attributes, consumer_worker_thread, self ) < 0 ) {
 				if ( pthread_create( thread, NULL, consumer_worker_thread, self ) == 0 )
 					mlt_deque_push_back( priv->worker_threads, thread );
+			} else {
+				mlt_deque_push_back( priv->worker_threads, thread );
+			}
 			thread++;
 		}
 		pthread_attr_destroy( &thread_attributes );
@@ -1386,8 +1391,8 @@ static mlt_frame worker_get_frame( mlt_consumer self, mlt_properties properties
 	int buffer = mlt_properties_get_int( properties, "_buffer" );
 	buffer = buffer > 0 ? buffer : mlt_properties_get_int( properties, "buffer" );
 	// This is a heuristic to determine a suitable minimum buffer size for the number of threads.
-	int headroom = 2 + threads * threads;
-	buffer = buffer < headroom ? headroom : buffer;
+	int headroom = (priv->real_time < 0) ? threads : (2 + threads * threads);
+	buffer = MAX(buffer, headroom);
 
 	// Start worker threads if not already started.
 	if ( ! priv->ahead )
@@ -1416,6 +1421,8 @@ static mlt_frame worker_get_frame( mlt_consumer self, mlt_properties properties
 				mlt_deque_push_back( priv->queue, frame );
 				pthread_cond_signal( &priv->queue_cond );
 				pthread_mutex_unlock( &priv->queue_mutex );
+				priv->speed = mlt_properties_get_int( MLT_FRAME_PROPERTIES( frame ), "_speed" );
+				buffer = (priv->speed == 0) ? 1 : buffer;
 			}
 		}
 
@@ -1448,6 +1455,8 @@ static mlt_frame worker_get_frame( mlt_consumer self, mlt_properties properties
 			mlt_deque_push_back( priv->queue, frame );
 			pthread_cond_signal( &priv->queue_cond );
 			pthread_mutex_unlock( &priv->queue_mutex );
+			priv->speed = mlt_properties_get_int( MLT_FRAME_PROPERTIES( frame ), "_speed" );
+			buffer = (priv->speed == 0) ? 1 : buffer;
 		}
 	}
 
@@ -1566,7 +1575,7 @@ mlt_frame mlt_consumer_rt_frame( mlt_consumer self )
 #ifndef _WIN32
 			consumer_read_ahead_start( self );
 #endif
-			if ( buffer > 1 )
+			if ( buffer > 1 && priv->speed )
 				size = prefill > 0 && prefill < buffer ? prefill : buffer;
 			priv->preroll = 0;
 		}
@@ -1633,7 +1642,7 @@ void mlt_consumer_stopped( mlt_consumer self )
 
 int mlt_consumer_stop( mlt_consumer self )
 {
-	// Get the properies
+	// Get the properties
 	mlt_properties properties = MLT_CONSUMER_PROPERTIES( self );
 	consumer_private *priv = self->local;
 
